#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {
    switch $tcl_platform(platform) {
	windows {
	}
	default {
	    option add *Scrollbar.width 10
	}
    }
    
}
#############################################################################
# Visual Tcl v1.51 Project
#

#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
proc Window {args} {
    global vTcl
    set cmd     [lindex $args 0]
    set name    [lindex $args 1]
    set newname [lindex $args 2]
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}

proc vTcl:WindowsCleanup {} {
    global vTcl
    if {[info exists vTcl(sourcing)]} { return }
    foreach w [winfo children .] {
    	wm protocol $w WM_DELETE_WINDOW { exit }
    }
}
}

if {![info exists vTcl(sourcing)]} {
proc {vTcl:DefineAlias} {target alias widgetProc top_or_alias cmdalias} {
    global widget

    set widget($alias) $target
    set widget(rev,$target) $alias

    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }

    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target

        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}

proc {vTcl:DoCmdOption} {target cmd} {
    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}

proc {vTcl:FireEvent} {target event} {
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                regsub -all %W $bind_code $target bind_code
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    # break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}

proc {vTcl:Toplevel:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        return -code error "wrong # args: should be \"$w option ?arg arg ...?\""
    }

    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure

        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }

    switch -- $command {
        "hide" -
        "Hide" {
            Window hide $w
        }

        "show" -
        "Show" {
            Window show $w
        }

        "ShowModal" {
            Window show $w
            raise $w
            grab $w
            tkwait window $w
            grab release $w
        }

        default {
            eval $w $command $args
        }
    }
}

proc {vTcl:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        return -code error "wrong # args: should be \"$w option ?arg arg ...?\""
    }

    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure

        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }

    eval $w $command $args
}

proc {vTcl:toplevel} {args} {
    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {}
}
}

if {[info exists vTcl(sourcing)]} {
proc vTcl:project:info {} {
    namespace eval ::widgets::.top22 {
        array set save {}
    }
    namespace eval ::widgets::.top22.fra34 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38 {
        array set save {-borderwidth 1 -relief 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38.fra28 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38.fra28.but41 {
        array set save {-command 1 -padx 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38.fra28.but29 {
        array set save {-command 1 -padx 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38.fra28.but40 {
        array set save {-command 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38.fra28.but39 {
        array set save {-pady 1 -text 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38.fra28.but22 {
        array set save {-command 1 -padx 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38.fra28.but23 {
        array set save {-command 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38.fra28.but24 {
        array set save {-command 1 -pady 1 -text 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38.fra28.che22 {
        array set save {-text 1 -variable 1}
    }
    namespace eval ::widgets::.top22.fra34.fra38.fra28.che23 {
        array set save {-text 1 -variable 1}
    }
    namespace eval ::widgets::.top22.fra35 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top22.fra35.fra37 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top22.fra35.fra37.cpd31 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top22.fra35.fra37.cpd31.01 {
        array set save {-anchor 1 -padx 1 -pady 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top22.fra35.fra37.cpd31.02 {
        array set save {-cursor 1 -font 1 -textvariable 1}
    }
    namespace eval ::widgets::.top22.fra35.fra37.fra32 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top22.fra35.fra37.fra32.01 {
        array set save {-anchor 1 -padx 1 -pady 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top22.fra35.fra37.fra32.02 {
        array set save {-cursor 1 -font 1 -textvariable 1}
    }
    namespace eval ::widgets::.top22.fra36 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top22.fra36.cpd42 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top22.fra36.cpd42.01 {
        array set save {-command 1 -orient 1}
    }
    namespace eval ::widgets::.top22.fra36.cpd42.02 {
        array set save {-command 1}
    }
    namespace eval ::widgets::.top22.fra36.cpd42.03 {
        array set save {-font 1 -height 1 -width 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist {}
    }
}
}
#################################
# USER DEFINED PROCEDURES
#
###########################################################
## Procedure:  dobrowse

proc {dobrowse} {} {
global widget xgiffile lastdir
	set types {
		{{gif Files}        {.gif}        }
		{{jpg Files}        {.jpg}        }
		{{All Files}        *             }
	}

	if ![info exists lastdir] {set lastdir [pwd]}
	set filename  [tk_getOpenFile -title "gif file" -filetypes $types -initialdir $lastdir]
	if {$filename == ""} {
		return ""
	}
	set lastdir [file dirname $filename]
	set xgiffile $filename
}
###########################################################
## Procedure:  doclear

proc {doclear} {} {
global widget
	$widget(Text1) delete 1.0 end
}
###########################################################
## Procedure:  dogen

proc {dogen} {} {
global widget xgiffile xprocname im xexample  xdelay 
	doclear
	foreach file [glob $xgiffile] {
		set name $xprocname
		if {$name == ""} {
		  set name [file tail $file]
		}

		package require base64
		set fileID [open $file RDONLY]
		fconfigure $fileID -translation binary
		set rawData [read $fileID]
		close $fileID
		set encodedData [base64::encode $rawData]

		xputs "proc \{$name\} \{\} {"
		xputs "return \[image create photo -data \"$encodedData\"\]"
		xputs "}"

		set im [image create photo -data $encodedData]
		Button3 configure -image $im

		if {$xexample} {
			xputs "\n\nButton2 configure -image \[$name\]"
		}
		if {$xdelay} {
			update
			after 1000
		}
	}
}
###########################################################
## Procedure:  foo_down

proc {foo_down} {} {
global widget

return [image create photo -data "R0lGODlhDgANAJEAAAAAAP///wAAgMDAwCwAAAAADgANAAACGpwtebspDB1k
cp5qB26ub99FoOVlmmJqqVkAADs="]
}
###########################################################
## Procedure:  saveas

proc {saveas} {} {
global widget
	set types {
		{{txt Files}        {.tcl}        }
		{{All Files}        *             }
	}
	
		
		set filename  [tk_getSaveFile -title "Config File To Save" -filetypes $types]
		if {$filename == ""} {
			return ""
		}
		if {[file exists $filename]} {
			file copy -force $filename "$filename.bak"
			xputs "created backup $filename.bak"
		}
		if { [catch {  set fileid     [open $filename "w"]         } mess] } {
		   xputs "Cannot create file - $mess" red
		   return ""
		} 
        puts $fileid [Text1 get 1.0 end-1c]
        close $fileid
		xputs "save as ... $filename"
}
###########################################################
## Procedure:  xputs

proc {xputs} {text} {
global widget

	$widget(Text1) insert end  "$text\n" 
	$widget(Text1) see end
}
###########################################################
## Procedure:  init
###########################################################
## Procedure:  main

proc {main} {argc argv} {
wm protocol .top22 WM_DELETE_WINDOW {exit}
if ![info exists ::vTcl] {
	
	Text1 configure -font {courier 10} -wrap none

xputs "
To begin, choose open, to find a file. Or fill in the file name above.
Wildcards are ok. You can browse to a file, then change to wildcards.

Then choose to write code (to this text window) and then save everything
in this window to a file.

You can have an example line of code generated if you want.

Leave the proc name blank to have the proc name generated using the
name of the file.

You can select all in this window with conrol-home then shift control-end.

You can use Button2 for testing. If you have a wildcard name, use delay 1 second
if you want to see each image briefly (in button3) as the code is generated.

Console only works on windows.
"
	
}
}

proc init {argc argv} {

}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base {container 0}} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    wm focusmodel $base passive
    wm geometry $base 200x200+192+192; update
    wm maxsize $base 2180 847
    wm minsize $base 124 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm withdraw $base
    wm title $base "vtcl"
    bindtags $base "$base Vtcl all"
    vTcl:FireEvent $base <<Create>>
    }
    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top22 {base {container 0}} {
    if {$base == ""} {
        set base .top22
    }
    if {[winfo exists $base] && (!$container)} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "Toplevel1" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.fra34" "Frame10" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38" "Frame1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38.fra28" "Frame6" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38.fra28.but22" "Button5" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38.fra28.but23" "Button6" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38.fra28.but24" "Button7" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38.fra28.but29" "Button1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38.fra28.but39" "Button2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38.fra28.but40" "Button3" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38.fra28.but41" "Button4" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38.fra28.che22" "Checkbutton1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra34.fra38.fra28.che23" "Checkbutton2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra35" "Frame11" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra35.fra37" "Frame2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra35.fra37.cpd31" "Frame7" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra35.fra37.cpd31.01" "Label1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra35.fra37.cpd31.02" "procname" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra35.fra37.fra32" "Frame8" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra35.fra37.fra32.01" "Label2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra35.fra37.fra32.02" "giffile" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra36" "Frame12" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra36.cpd42" "Frame13" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra36.cpd42.01" "Scrollbar1" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra36.cpd42.02" "Scrollbar2" vTcl:WidgetProc "Toplevel1" 1
    vTcl:DefineAlias "$base.fra36.cpd42.03" "Text1" vTcl:WidgetProc "Toplevel1" 1

    ###################
    # CREATING WIDGETS
    ###################
    if {!$container} {
    vTcl:toplevel $base -class Toplevel
    wm focusmodel $base passive
    wm geometry $base 712x603+-4+2; update
    wm maxsize $base 2180 847
    wm minsize $base 124 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm deiconify $base
    wm title $base "gif code gen"
    vTcl:FireEvent $base <<Create>>
    }
    frame $base.fra34 \
        -borderwidth 2 -height 75 -relief groove -width 125 
    frame $base.fra34.fra38 \
        -borderwidth 2 -relief groove 
    frame $base.fra34.fra38.fra28 \
        -borderwidth 2 -height 75 -relief groove -width 125 
    button $base.fra34.fra38.fra28.but41 \
        -command dobrowse -padx 1 -pady 0 -text Open... 
    button $base.fra34.fra38.fra28.but29 \
        -command dogen -padx 1 -pady 0 -text {Write Code} 
    button $base.fra34.fra38.fra28.but40 \
        -command {global im
Button3 configure -image $im} -pady 0 \
        -text button3 
    button $base.fra34.fra38.fra28.but39 \
        -pady 0 -text button2 
    button $base.fra34.fra38.fra28.but22 \
        -command saveas -padx 1 -pady 0 -text {Save to file...} 
    button $base.fra34.fra38.fra28.but23 \
        -command doclear -pady 0 -text Clear 
    button $base.fra34.fra38.fra28.but24 \
        -command {catch {console show}} -pady 0 -text Console 
    checkbutton $base.fra34.fra38.fra28.che22 \
        -text {example use} -variable xexample 
    checkbutton $base.fra34.fra38.fra28.che23 \
        -text {delay 1 sec} -variable xdelay 
    frame $base.fra35 \
        -borderwidth 2 -height 75 -relief groove -width 125 
    frame $base.fra35.fra37 \
        -borderwidth 2 -height 75 -relief groove -width 125 
    frame $base.fra35.fra37.cpd31 \
        -borderwidth 1 -height 30 -relief raised -width 30 
    label $base.fra35.fra37.cpd31.01 \
        -anchor w -padx 1 -pady 1 -relief groove -text {proc name} 
    entry $base.fra35.fra37.cpd31.02 \
        -cursor {} -font {courier 10} -textvariable xprocname 
    frame $base.fra35.fra37.fra32 \
        -borderwidth 1 -height 30 -relief raised -width 30 
    label $base.fra35.fra37.fra32.01 \
        -anchor w -padx 1 -pady 1 -relief groove -text {gif file} 
    entry $base.fra35.fra37.fra32.02 \
        -cursor {} -font {courier 10} -textvariable xgiffile 
    frame $base.fra36 \
        -borderwidth 2 -height 75 -relief groove -width 125 
    frame $base.fra36.cpd42 \
        -borderwidth 1 -height 30 -relief raised -width 30 
    scrollbar $base.fra36.cpd42.01 \
        -command "$base.fra36.cpd42.03 xview" -orient horizontal 
    scrollbar $base.fra36.cpd42.02 \
        -command "$base.fra36.cpd42.03 yview" 
    text $base.fra36.cpd42.03 \
        -font -Adobe-Helvetica-Medium-R-Normal-*-*-120-*-*-*-*-*-* -height 10 \
        -width 20 -xscrollcommand "$base.fra36.cpd42.01 set" \
        -yscrollcommand "$base.fra36.cpd42.02 set" 
    ###################
    # SETTING GEOMETRY
    ###################
    pack $base.fra34 \
        -in $base -anchor center -expand 0 -fill both -side top 
    pack $base.fra34.fra38 \
        -in $base.fra34 -anchor center -expand 0 -fill none -side left 
    pack $base.fra34.fra38.fra28 \
        -in $base.fra34.fra38 -anchor center -expand 0 -fill none -side top 
    pack $base.fra34.fra38.fra28.but41 \
        -in $base.fra34.fra38.fra28 -anchor center -expand 0 -fill none \
        -side left 
    pack $base.fra34.fra38.fra28.but29 \
        -in $base.fra34.fra38.fra28 -anchor center -expand 0 -fill none \
        -side left 
    pack $base.fra34.fra38.fra28.but40 \
        -in $base.fra34.fra38.fra28 -anchor center -expand 0 -fill none \
        -side right 
    pack $base.fra34.fra38.fra28.but39 \
        -in $base.fra34.fra38.fra28 -anchor center -expand 0 -fill none \
        -side right 
    pack $base.fra34.fra38.fra28.but22 \
        -in $base.fra34.fra38.fra28 -anchor center -expand 0 -fill none \
        -side left 
    pack $base.fra34.fra38.fra28.but23 \
        -in $base.fra34.fra38.fra28 -anchor center -expand 0 -fill none \
        -side left 
    pack $base.fra34.fra38.fra28.but24 \
        -in $base.fra34.fra38.fra28 -anchor center -expand 0 -fill none \
        -side left 
    pack $base.fra34.fra38.fra28.che22 \
        -in $base.fra34.fra38.fra28 -anchor center -expand 0 -fill none \
        -side left 
    pack $base.fra34.fra38.fra28.che23 \
        -in $base.fra34.fra38.fra28 -anchor center -expand 0 -fill none \
        -side left 
    pack $base.fra35 \
        -in $base -anchor center -expand 0 -fill both -side top 
    pack $base.fra35.fra37 \
        -in $base.fra35 -anchor center -expand 1 -fill x -side left 
    pack $base.fra35.fra37.cpd31 \
        -in $base.fra35.fra37 -anchor center -expand 0 -fill x -side top 
    pack $base.fra35.fra37.cpd31.01 \
        -in $base.fra35.fra37.cpd31 -anchor center -expand 0 -fill none \
        -padx 2 -pady 2 -side left 
    pack $base.fra35.fra37.cpd31.02 \
        -in $base.fra35.fra37.cpd31 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    pack $base.fra35.fra37.fra32 \
        -in $base.fra35.fra37 -anchor center -expand 1 -fill x -side top 
    pack $base.fra35.fra37.fra32.01 \
        -in $base.fra35.fra37.fra32 -anchor center -expand 0 -fill none \
        -padx 2 -pady 2 -side left 
    pack $base.fra35.fra37.fra32.02 \
        -in $base.fra35.fra37.fra32 -anchor center -expand 1 -fill x -padx 2 \
        -pady 2 -side right 
    pack $base.fra36 \
        -in $base -anchor center -expand 1 -fill both -side top 
    pack $base.fra36.cpd42 \
        -in $base.fra36 -anchor center -expand 1 -fill both -side top 
    grid columnconf $base.fra36.cpd42 0 -weight 1
    grid rowconf $base.fra36.cpd42 0 -weight 1
    grid $base.fra36.cpd42.01 \
        -in $base.fra36.cpd42 -column 0 -row 1 -columnspan 1 -rowspan 1 \
        -sticky ew 
    grid $base.fra36.cpd42.02 \
        -in $base.fra36.cpd42 -column 1 -row 0 -columnspan 1 -rowspan 1 \
        -sticky ns 
    grid $base.fra36.cpd42.03 \
        -in $base.fra36.cpd42 -column 0 -row 0 -columnspan 1 -rowspan 1 \
        -sticky nesw 

    vTcl:FireEvent $base <<Ready>>
}

Window show .
Window show .top22

main $argc $argv
